#!/usr/bin/perl
# Do not normalise this test file. It has deliberately unnormalised characters in it.
use v5.10;
use strict;
use warnings;
use utf8;
use if $^V ge v5.12.0, feature => 'unicode_strings';

use Test::More tests => 24;
use Test::Exception;

use ok 'Locale::CLDR';

my $locale = Locale::CLDR->new('da_DK');
my $other_locale = Locale::CLDR->new('en_US');

is($locale->locale_name(), 'dansk (Danmark)', 'Locale name from current locale');
is($locale->locale_name('fr_CA'), 'canadisk fransk', 'Locale name from string');
is($locale->locale_name($other_locale), 'amerikansk engelsk', 'Locale name from other locale object');

is($locale->language_name(), 'dansk', 'Language name from current locale');
is($locale->language_name('fr'), 'fransk', 'Language name from string');
is($locale->language_name($other_locale), 'engelsk', 'Language name from other locale object');

my $all_languages = {
    'aa' => 'afar',
    'ab' => 'abkhasisk',
    'ace' => 'achinesisk',
    'ach' => 'acoli',
    'ada' => 'adangme',
    'ady' => 'adyghe',
    'ae' => 'avestan',
    'af' => 'afrikaans',
    'afh' => 'afrihili',
    'agq' => 'aghem',
    'ain' => 'ainu',
    'ak' => 'akan',
    'akk' => 'akkadisk',
    'ale' => 'aleutisk',
    'alt' => 'sydaltaisk',
    'am' => 'amharisk',
    'an' => 'aragonsk',
    'ang' => 'oldengelsk',
    'ann' => 'obolo',
    'anp' => 'angika',
    'ar' => 'arabisk',
    'ar_001' => 'moderne standardarabisk',
    'arc' => 'aramæisk',
    'arn' => 'mapudungun',
    'arp' => 'arapaho',
    'ars' => 'Najd-arabisk',
    'ars@alt=menu' => 'arabisk, najdi',
    'arw' => 'arawak',
    'as' => 'assamesisk',
    'asa' => 'asu',
    'ast' => 'asturisk',
    'atj' => 'atikamekw',
    'av' => 'avarisk',
    'awa' => 'awadhi',
    'ay' => 'aymara',
    'az' => 'aserbajdsjansk',
    'az@alt=short' => 'azeri',
    'ba' => 'bashkir',
    'bal' => 'baluchi',
    'ban' => 'balinesisk',
    'bas' => 'basaa',
    'bax' => 'bamun',
    'bbj' => 'ghomala',
    'be' => 'belarusisk',
    'bej' => 'beja',
    'bem' => 'bemba',
    'bez' => 'bena',
    'bfd' => 'bafut',
    'bg' => 'bulgarsk',
    'bgc' => 'harianvi',
    'bgn' => 'vestbaluchi',
    'bho' => 'bhojpuri',
    'bi' => 'bislama',
    'bik' => 'bikol',
    'bin' => 'bini',
    'bkm' => 'kom',
    'bla' => 'siksika',
    'blo' => 'anii',
    'bm' => 'bambara',
    'bn' => 'bengali',
    'bo' => 'tibetansk',
    'br' => 'bretonsk',
    'bra' => 'braj',
    'brx' => 'bodo',
    'bs' => 'bosnisk',
    'bss' => 'bakossi',
    'bua' => 'buriatisk',
    'bug' => 'buginesisk',
    'bum' => 'bulu',
    'byn' => 'blin',
    'byv' => 'medumba',
    'ca' => 'catalansk',
    'cad' => 'caddo',
    'car' => 'caribisk',
    'cay' => 'cayuga',
    'cch' => 'atsam',
    'ccp' => 'chakma',
    'ce' => 'tjetjensk',
    'ceb' => 'cebuano',
    'cgg' => 'chiga',
    'ch' => 'chamorro',
    'chb' => 'chibcha',
    'chg' => 'chagatai',
    'chk' => 'chuukese',
    'chm' => 'mari',
    'chn' => 'chinook',
    'cho' => 'choctaw',
    'chp' => 'chipewyan',
    'chr' => 'cherokee',
    'chy' => 'cheyenne',
    'ckb' => 'sorani',
    'ckb@alt=menu' => 'kurdisk, sorani',
    'ckb@alt=variant' => 'centralkurdisk',
    'clc' => 'chilcotin',
    'co' => 'korsikansk',
    'cop' => 'koptisk',
    'cr' => 'cree',
    'crg' => 'michif',
    'crh' => 'krimtatarisk',
    'crj' => 'sydøstcree',
    'crk' => 'plains cree',
    'crl' => 'nordøstcree',
    'crm' => 'Moose-cree',
    'crr' => 'carolina algonquisk',
    'crs' => 'seselwa (kreol-fransk)',
    'cs' => 'tjekkisk',
    'csb' => 'kasjubisk',
    'csw' => 'swampy cree',
    'cu' => 'kirkeslavisk',
    'cv' => 'tjuvasjisk',
    'cy' => 'walisisk',
    'da' => 'dansk',
    'dak' => 'dakota',
    'dar' => 'dargwa',
    'dav' => 'taita',
    'de' => 'tysk',
    'de_AT' => 'østrigsk tysk',
    'de_CH' => 'schweizerhøjtysk',
    'del' => 'delaware',
    'den' => 'athapaskisk',
    'dgr' => 'dogrib',
    'din' => 'dinka',
    'dje' => 'zarma',
    'doi' => 'dogri',
    'dsb' => 'nedersorbisk',
    'dua' => 'duala',
    'dum' => 'middelhollandsk',
    'dv' => 'divehi',
    'dyo' => 'jola-fonyi',
    'dyu' => 'dyula',
    'dz' => 'dzongkha',
    'dzg' => 'dazaga',
    'ebu' => 'kiembu',
    'ee' => 'ewe',
    'efi' => 'efik',
    'egy' => 'oldegyptisk',
    'eka' => 'ekajuk',
    'el' => 'græsk',
    'elx' => 'elamitisk',
    'en' => 'engelsk',
    'en_AU' => 'australsk engelsk',
    'en_CA' => 'canadisk engelsk',
    'en_GB' => 'britisk engelsk',
    'en_US' => 'amerikansk engelsk',
    'enm' => 'middelengelsk',
    'eo' => 'esperanto',
    'es' => 'spansk',
    'es_419' => 'latinamerikansk spansk',
    'es_ES' => 'europæisk spansk',
    'es_MX' => 'mexicansk spansk',
    'et' => 'estisk',
    'eu' => 'baskisk',
    'ewo' => 'ewondo',
    'fa' => 'persisk',
    'fa_AF' => 'dari',
    'fan' => 'fang',
    'fat' => 'fanti',
    'ff' => 'fulah',
    'fi' => 'finsk',
    'fil' => 'filippinsk',
    'fj' => 'fijiansk',
    'fo' => 'færøsk',
    'fon' => 'fon',
    'fr' => 'fransk',
    'fr_CA' => 'canadisk fransk',
    'fr_CH' => 'schweizisk fransk',
    'frc' => 'cajunfransk',
    'frm' => 'middelfransk',
    'fro' => 'oldfransk',
    'frr' => 'nordfrisisk',
    'frs' => 'østfrisisk',
    'fur' => 'friulisk',
    'fy' => 'vestfrisisk',
    'ga' => 'irsk',
    'gaa' => 'ga',
    'gag' => 'gagauzisk',
    'gan' => 'gan-kinesisk',
    'gay' => 'gayo',
    'gba' => 'gbaya',
    'gd' => 'skotsk gælisk',
    'gez' => 'geez',
    'gil' => 'gilbertesisk',
    'gl' => 'galicisk',
    'gmh' => 'middelhøjtysk',
    'gn' => 'guarani',
    'goh' => 'oldhøjtysk',
    'gon' => 'gondi',
    'gor' => 'gorontalo',
    'got' => 'gotisk',
    'grb' => 'grebo',
    'grc' => 'oldgræsk',
    'gsw' => 'schweizertysk',
    'gu' => 'gujarati',
    'guz' => 'gusii',
    'gv' => 'manx',
    'gwi' => 'gwichin',
    'ha' => 'hausa',
    'hai' => 'haida',
    'hak' => 'hakka-kinesisk',
    'haw' => 'hawaiiansk',
    'hax' => 'sydhaida',
    'he' => 'hebraisk',
    'hi' => 'hindi',
    'hi_Latn@alt=variant' => 'hinglish',
    'hil' => 'hiligaynon',
    'hit' => 'hittitisk',
    'hmn' => 'hmong',
    'ho' => 'hirimotu',
    'hr' => 'kroatisk',
    'hsb' => 'øvresorbisk',
    'hsn' => 'xiang-kinesisk',
    'ht' => 'haitisk',
    'hu' => 'ungarsk',
    'hup' => 'hupa',
    'hur' => 'halkomelem',
    'hy' => 'armensk',
    'hz' => 'herero',
    'ia' => 'interlingua',
    'iba' => 'iban',
    'ibb' => 'ibibio',
    'id' => 'indonesisk',
    'ie' => 'interlingue',
    'ig' => 'igbo',
    'ii' => 'sichuan yi',
    'ik' => 'inupiaq',
    'ikt' => 'vestcanadisk inuktitut',
    'ilo' => 'iloko',
    'inh' => 'ingush',
    'io' => 'ido',
    'is' => 'islandsk',
    'it' => 'italiensk',
    'iu' => 'inuktitut',
    'ja' => 'japansk',
    'jbo' => 'lojban',
    'jgo' => 'ngomba',
    'jmc' => 'machame',
    'jpr' => 'jødisk-persisk',
    'jrb' => 'jødisk-arabisk',
    'jv' => 'javanesisk',
    'ka' => 'georgisk',
    'kaa' => 'karakalpakisk',
    'kab' => 'kabylsk',
    'kac' => 'kachin',
    'kaj' => 'jju',
    'kam' => 'kamba',
    'kaw' => 'kawi',
    'kbd' => 'kabardian',
    'kbl' => 'kanembu',
    'kcg' => 'tyap',
    'kde' => 'makonde',
    'kea' => 'kapverdisk',
    'kfo' => 'koro',
    'kg' => 'kongo',
    'kgp' => 'kaingang',
    'kha' => 'khasi',
    'kho' => 'khotanesisk',
    'khq' => 'koyra-chiini',
    'ki' => 'kikuyu',
    'kj' => 'kuanyama',
    'kk' => 'kasakhisk',
    'kkj' => 'kako',
    'kl' => 'grønlandsk',
    'kln' => 'kalenjin',
    'km' => 'khmer',
    'kmb' => 'kimbundu',
    'kn' => 'kannada',
    'ko' => 'koreansk',
    'koi' => 'komi-permjakisk',
    'kok' => 'konkani',
    'kos' => 'kosraean',
    'kpe' => 'kpelle',
    'kr' => 'kanuri',
    'krc' => 'karatjai-balkar',
    'krl' => 'karelsk',
    'kru' => 'kurukh',
    'ks' => 'kashmiri',
    'ksb' => 'shambala',
    'ksf' => 'bafia',
    'ksh' => 'kölsch',
    'ku' => 'kurdisk',
    'kum' => 'kymyk',
    'kut' => 'kutenaj',
    'kv' => 'komi',
    'kw' => 'cornisk',
    'kwk' => 'kwakʼwala',
    'kxv' => 'kuvi',
    'ky' => 'kirgisisk',
    'la' => 'latin',
    'lad' => 'ladino',
    'lag' => 'langi',
    'lah' => 'lahnda',
    'lam' => 'lamba',
    'lb' => 'luxembourgsk',
    'lez' => 'lezghian',
    'lg' => 'ganda',
    'li' => 'limburgsk',
    'lij' => 'ligurisk',
    'lil' => 'lillooet',
    'lkt' => 'lakota',
    'lmo' => 'lombardisk',
    'ln' => 'lingala',
    'lo' => 'lao',
    'lol' => 'mongo',
    'lou' => 'Louisiana-kreolsk',
    'loz' => 'lozi',
    'lrc' => 'nordluri',
    'lsm' => 'saamia',
    'lt' => 'litauisk',
    'lu' => 'luba-Katanga',
    'lua' => 'luba-Lulua',
    'lui' => 'luiseno',
    'lun' => 'lunda',
    'lus' => 'lushai',
    'luy' => 'luyana',
    'lv' => 'lettisk',
    'mad' => 'madurese',
    'maf' => 'mafa',
    'mag' => 'magahi',
    'mai' => 'maithili',
    'mak' => 'makasar',
    'man' => 'mandingo',
    'mas' => 'masai',
    'mde' => 'maba',
    'mdf' => 'moksha',
    'mdr' => 'mandar',
    'men' => 'mende',
    'mer' => 'meru',
    'mfe' => 'morisyen',
    'mg' => 'malagassisk',
    'mga' => 'middelirsk',
    'mgh' => 'makhuwa-meetto',
    'mgo' => 'meta',
    'mh' => 'marshallese',
    'mi' => 'maori',
    'mic' => 'micmac',
    'min' => 'minangkabau',
    'mk' => 'makedonsk',
    'ml' => 'malayalam',
    'mn' => 'mongolsk',
    'mnc' => 'manchu',
    'mni' => 'manipuri',
    'moe' => 'innu-aimun',
    'moh' => 'mohawk',
    'mos' => 'mossi',
    'mr' => 'marathi',
    'ms' => 'malajisk',
    'mt' => 'maltesisk',
    'mua' => 'mundang',
    'mul' => 'flere sprog',
    'mus' => 'creek',
    'mwl' => 'mirandesisk',
    'mwr' => 'marwari',
    'my' => 'burmesisk',
    'mye' => 'myene',
    'myv' => 'erzya',
    'mzn' => 'mazenisk',
    'na' => 'nauru',
    'nan' => 'min-kinesisk',
    'nap' => 'napolitansk',
    'naq' => 'nama',
    'nb' => 'bokmål',
    'nd' => 'nordndebele',
    'nds' => 'nedertysk',
    'nds_NL' => 'plattysk (Holland)',
    'ne' => 'nepalesisk',
    'new' => 'newari',
    'ng' => 'ndonga',
    'nia' => 'nias',
    'niu' => 'niueansk',
    'nl' => 'nederlandsk',
    'nl_BE' => 'flamsk',
    'nmg' => 'kwasio',
    'nn' => 'nynorsk',
    'nnh' => 'ngiemboon',
    'no' => 'norsk',
    'nog' => 'nogai',
    'non' => 'oldislandsk',
    'nqo' => 'n’ko',
    'nr' => 'sydndebele',
    'nso' => 'nordsotho',
    'nus' => 'nuer',
    'nv' => 'navajo',
    'nwc' => 'klassisk newarisk',
    'ny' => 'nyanja',
    'nym' => 'nyamwezi',
    'nyn' => 'nyankole',
    'nyo' => 'nyoro-sprog',
    'nzi' => 'nzima',
    'oc' => 'occitansk',
    'oj' => 'ojibwa',
    'ojb' => 'nordvestojibwa',
    'ojc' => 'centralojibwa',
    'ojs' => 'oji-cree',
    'ojw' => 'vestojibwa',
    'oka' => 'okanagan',
    'om' => 'oromo',
    'or' => 'oriya',
    'os' => 'ossetisk',
    'osa' => 'osage',
    'ota' => 'osmannisk tyrkisk',
    'pa' => 'punjabi',
    'pag' => 'pangasinan',
    'pal' => 'pahlavi',
    'pam' => 'pampanga',
    'pap' => 'papiamento',
    'pau' => 'palauansk',
    'pcm' => 'nigeriansk pidgin',
    'peo' => 'oldpersisk',
    'phn' => 'fønikisk',
    'pi' => 'pali',
    'pis' => 'pijin',
    'pl' => 'polsk',
    'pon' => 'ponape',
    'pqm' => 'maliseet-passamaquoddy',
    'prg' => 'preussisk',
    'pro' => 'oldprovencalsk',
    'ps' => 'pashto',
    'ps@alt=variant' => 'pushto',
    'pt' => 'portugisisk',
    'pt_BR' => 'brasiliansk portugisisk',
    'pt_PT' => 'europæisk portugisisk',
    'qu' => 'quechua',
    'quc' => 'quiché',
    'raj' => 'rajasthani',
    'rap' => 'rapanui',
    'rar' => 'rarotonga',
    'rhg' => 'rohingya',
    'rm' => 'rætoromansk',
    'rn' => 'rundi',
    'ro' => 'rumænsk',
    'ro_MD' => 'moldovisk',
    'rof' => 'rombo',
    'rom' => 'romani',
    'ru' => 'russisk',
    'rup' => 'arumænsk',
    'rw' => 'kinyarwanda',
    'rwk' => 'rwa',
    'sa' => 'sanskrit',
    'sad' => 'sandawe',
    'sah' => 'jakutisk',
    'sam' => 'samaritansk aramæisk',
    'saq' => 'samburu',
    'sas' => 'sasak',
    'sat' => 'santali',
    'sba' => 'ngambay',
    'sbp' => 'sangu',
    'sc' => 'sardinsk',
    'scn' => 'siciliansk',
    'sco' => 'skotsk',
    'sd' => 'sindhi',
    'sdh' => 'sydkurdisk',
    'se' => 'nordsamisk',
    'see' => 'seneca',
    'seh' => 'sena',
    'sel' => 'selkupisk',
    'ses' => 'koyraboro senni',
    'sg' => 'sango',
    'sga' => 'oldirsk',
    'sh' => 'serbokroatisk',
    'shi' => 'tachelhit',
    'shn' => 'shan',
    'shu' => 'tchadisk arabisk',
    'si' => 'singalesisk',
    'sid' => 'sidamo',
    'sk' => 'slovakisk',
    'sl' => 'slovensk',
    'slh' => 'sydlushootseed',
    'sm' => 'samoansk',
    'sma' => 'sydsamisk',
    'smj' => 'lulesamisk',
    'smn' => 'enaresamisk',
    'sms' => 'skoltesamisk',
    'sn' => 'shona',
    'snk' => 'soninke',
    'so' => 'somali',
    'sog' => 'sogdiansk',
    'sq' => 'albansk',
    'sr' => 'serbisk',
    'srn' => 'sranan tongo',
    'srr' => 'serer',
    'ss' => 'swati',
    'ssy' => 'saho',
    'st' => 'sydsotho',
    'str' => 'straits salish',
    'su' => 'sundanesisk',
    'suk' => 'sukuma',
    'sus' => 'susu',
    'sux' => 'sumerisk',
    'sv' => 'svensk',
    'sw' => 'swahili',
    'sw_CD' => 'congolesisk swahili',
    'swb' => 'comorisk',
    'syc' => 'klassisk syrisk',
    'syr' => 'syrisk',
    'szl' => 'schlesisk',
    'ta' => 'tamil',
    'tce' => 'sydtutchone',
    'te' => 'telugu',
    'tem' => 'temne',
    'teo' => 'teso',
    'ter' => 'tereno',
    'tet' => 'tetum',
    'tg' => 'tadsjikisk',
    'tgx' => 'tagish',
    'th' => 'thai',
    'tht' => 'tahltan',
    'ti' => 'tigrinya',
    'tig' => 'tigre',
    'tiv' => 'tivi',
    'tk' => 'turkmensk',
    'tkl' => 'tokelau',
    'tl' => 'tagalog',
    'tlh' => 'klingon',
    'tli' => 'tlingit',
    'tmh' => 'tamashek',
    'tn' => 'tswana',
    'to' => 'tongansk',
    'tog' => 'nyasa tongansk',
    'tok' => 'toki pona',
    'tpi' => 'tok pisin',
    'tr' => 'tyrkisk',
    'trv' => 'taroko',
    'ts' => 'tsonga',
    'tsi' => 'tsimshisk',
    'tt' => 'tatarisk',
    'ttm' => 'nordtutchone',
    'tum' => 'tumbuka',
    'tvl' => 'tuvaluansk',
    'tw' => 'twi',
    'twq' => 'tasawaq',
    'ty' => 'tahitiansk',
    'tyv' => 'tuvinian',
    'tzm' => 'centralmarokkansk tamazight',
    'udm' => 'udmurt',
    'ug' => 'uygurisk',
    'ug@alt=variant' => 'uighurisk',
    'uga' => 'ugaristisk',
    'uk' => 'ukrainsk',
    'umb' => 'umbundu',
    'und' => 'ukendt sprog',
    'ur' => 'urdu',
    'uz' => 'usbekisk',
    've' => 'venda',
    'vec' => 'venetiansk',
    'vi' => 'vietnamesisk',
    'vmw' => 'makhuwa',
    'vo' => 'volapyk',
    'vot' => 'votisk',
    'vun' => 'vunjo',
    'wa' => 'vallonsk',
    'wae' => 'walsertysk',
    'wal' => 'walamo',
    'war' => 'waray',
    'was' => 'washo',
    'wbp' => 'walbiri',
    'wo' => 'wolof',
    'wuu' => 'wu-kinesisk',
    'xal' => 'kalmyk',
    'xh' => 'xhosa',
    'xnr' => 'kangri',
    'xog' => 'soga',
    'yao' => 'yao',
    'yap' => 'yapese',
    'yav' => 'yangben',
    'ybb' => 'yemba',
    'yi' => 'jiddisch',
    'yo' => 'yoruba',
    'yrl' => 'nheengatu',
    'yue' => 'kantonesisk',
    'yue@alt=menu' => 'kantonesisk (Kina)',
    'za' => 'zhuang',
    'zap' => 'zapotec',
    'zbl' => 'blissymboler',
    'zen' => 'zenaga',
    'zgh' => 'tamazight',
    'zh' => 'kinesisk',
    'zh@alt=menu' => 'mandarin (Kina)',
    'zh_Hans' => 'forenklet kinesisk',
    'zh_Hant' => 'traditionelt kinesisk',
    'zu' => 'zulu',
    'zun' => 'zuni',
    'zxx' => 'intet sprogligt indhold',
    'zza' => 'zaza',
};

is_deeply($locale->all_languages, $all_languages, 'All languages');

is($locale->script_name(), '', 'Script name from current locale');
is($locale->script_name('latn'), 'latinsk', 'Script name from string');
is($locale->script_name($other_locale), '', 'Script name from other locale object');

my $all_scripts = {
    'Adlm' => 'adlam',
	'Afak' => 'afaka',
	'Arab' => 'arabisk',
	'Arab@alt=variant' => 'persisk-arabisk',
	'Aran' => 'nastaliq',
	'Armi' => 'armi',
	'Armn' => 'armensk',
	'Avst' => 'avestansk',
	'Bali' => 'balinesisk',
	'Bamu' => 'bamum',
	'Bass' => 'bassa',
	'Batk' => 'batak',
	'Beng' => 'bengali',
	'Blis' => 'blissymboler',
	'Bopo' => 'bopomofo',
	'Brah' => 'bramisk',
	'Brai' => 'punktskrift',
	'Bugi' => 'buginesisk',
	'Buhd' => 'buhid',
	'Cakm' => 'chakma',
	'Cans' => 'oprindelige canadiske symboler',
	'Cari' => 'kariansk',
	'Cham' => 'cham',
	'Cher' => 'cherokee',
	'Cirt' => 'cirt',
	'Copt' => 'koptisk',
	'Cprt' => 'cypriotisk',
	'Cyrl' => 'kyrillisk',
	'Cyrs' => 'kyrillisk - oldkirkeslavisk variant',
	'Deva' => 'devanagari',
	'Dsrt' => 'deseret',
	'Dupl' => 'Duploya-stenografi',
	'Egyd' => 'egyptisk demotisk',
	'Egyh' => 'egyptisk hieratisk',
	'Egyp' => 'egyptiske hieroglyffer',
	'Ethi' => 'etiopisk',
	'Geok' => 'georgisk kutsuri',
	'Geor' => 'georgisk',
	'Glag' => 'glagolitisk',
	'Goth' => 'gotisk',
	'Gran' => 'grantha',
	'Grek' => 'græsk',
	'Gujr' => 'gujarati',
	'Guru' => 'gurmukhi',
	'Hanb' => 'han med bopomofo',
	'Hang' => 'hangul',
	'Hani' => 'han',
	'Hano' => 'hanunoo',
	'Hans' => 'forenklet',
	'Hans@alt=stand-alone' => 'forenklet han',
	'Hant' => 'traditionelt',
	'Hant@alt=stand-alone' => 'traditionelt han',
	'Hebr' => 'hebraisk',
	'Hira' => 'hiragana',
	'Hluw' => 'anatolske hieroglyffer',
	'Hmng' => 'pahawh hmong',
	'Hrkt' => 'japanske skrifttegn',
	'Hung' => 'oldungarsk',
	'Inds' => 'indus',
	'Ital' => 'Olditalisk',
	'Jamo' => 'jamo',
	'Java' => 'javanesisk',
	'Jpan' => 'japansk',
	'Jurc' => 'jurchen',
	'Kali' => 'kaya li',
	'Kana' => 'katakana',
	'Khar' => 'kharoshti',
	'Khmr' => 'khmer',
	'Khoj' => 'khojki',
	'Knda' => 'kannada',
	'Kore' => 'koreansk',
	'Kpel' => 'kpelle',
	'Kthi' => 'kthi',
	'Lana' => 'lanna',
	'Laoo' => 'lao',
	'Latf' => 'latinsk - frakturvariant',
	'Latg' => 'latinsk - gælisk variant',
	'Latn' => 'latinsk',
	'Lepc' => 'lepcha',
	'Limb' => 'limbu',
	'Lina' => 'lineær A',
	'Linb' => 'lineær B',
	'Lisu' => 'lisu',
	'Loma' => 'loma',
	'Lyci' => 'lykisk',
	'Lydi' => 'lydisk',
	'Mand' => 'mandaisk',
	'Mani' => 'manikæisk',
	'Maya' => 'mayahieroglyffer',
	'Mend' => 'mende',
	'Merc' => 'metroitisk sammenhængende',
	'Mero' => 'meroitisk',
	'Mlym' => 'malayalam',
	'Mong' => 'mongolsk',
	'Moon' => 'moon',
	'Mroo' => 'mroo',
	'Mtei' => 'meitei-mayek',
	'Mymr' => 'burmesisk',
	'Narb' => 'gammelt nordarabisk',
	'Nbat' => 'nabateisk',
	'Nkgb' => 'nakhi geba',
	'Nkoo' => 'n’ko',
	'Nshu' => 'nüshu',
	'Ogam' => 'ogham',
	'Olck' => 'ol-chiki',
	'Orkh' => 'orkhon',
	'Orya' => 'oriya',
	'Osma' => 'osmannisk',
	'Palm' => 'palmyrensk',
	'Perm' => 'oldpermisk',
	'Phag' => 'phags-pa',
	'Phli' => 'phli',
	'Phlp' => 'phlp',
	'Phlv' => 'pahlavi',
	'Phnx' => 'fønikisk',
	'Plrd' => 'pollardtegn',
	'Prti' => 'prti',
	'Qaag' => 'zawgyi',
	'Rjng' => 'rejang',
    'Rohg' => 'hanifi',
	'Roro' => 'rongo-rongo',
	'Runr' => 'runer',
	'Samr' => 'samaritansk',
	'Sara' => 'sarati',
	'Sarb' => 'oldsørarabisk',
	'Saur' => 'saurashtra',
	'Sgnw' => 'tegnskrift',
	'Shaw' => 'shavisk',
	'Shrd' => 'sharada',
	'Sind' => 'khudawadi',
	'Sinh' => 'singalesisk',
	'Sora' => 'sora',
	'Sund' => 'sundanesisk',
	'Sylo' => 'syloti nagri',
	'Syrc' => 'syrisk',
	'Syre' => 'syrisk - estrangelovariant',
	'Syrj' => 'vestsyrisk',
	'Syrn' => 'østsyriakisk',
	'Tagb' => 'tagbanwa',
	'Takr' => 'takri',
	'Tale' => 'tai le',
	'Talu' => 'tai lue',
	'Taml' => 'tamilsk',
	'Tang' => 'tangut',
	'Tavt' => 'tavt',
	'Telu' => 'telugu',
	'Teng' => 'tengwar',
	'Tfng' => 'tifinagh',
	'Tglg' => 'tagalog',
	'Thaa' => 'thaana',
	'Thai' => 'thailandsk',
	'Tibt' => 'tibetansk',
	'Tirh' => 'tirhuta',
	'Ugar' => 'ugaritisk',
	'Vaii' => 'vai',
	'Visp' => 'synlig tale',
	'Wara' => 'varang kshiti',
	'Wole' => 'woleai',
	'Xpeo' => 'oldpersisk',
	'Xsux' => 'sumero-akkadisk cuneiform',
	'Yiii' => 'yi',
	'Zinh' => 'arvet',
	'Zmth' => 'matematisk notation',
	'Zsye' => 'emoji',
	'Zsym' => 'symboler',
	'Zxxx' => 'uden skriftsprog',
	'Zyyy' => 'fælles',
	'Zzzz' => 'ukendt skriftsprog',
};

is_deeply($locale->all_scripts, $all_scripts, 'All scripts');

is($locale->region_name(), 'Danmark', 'Territory name from current locale');
is($locale->region_name('fr'), 'Frankrig', 'Territory name from string');
is($locale->region_name($other_locale), 'USA', 'Territory name from other locale object');

my $all_regions = {
	'001' => 'Verden',
	'002' => 'Afrika',
	'003' => 'Nordamerika',
	'005' => 'Sydamerika',
	'009' => 'Oceanien',
	'011' => 'Vestafrika',
	'013' => 'Mellemamerika',
	'014' => 'Østafrika',
	'015' => 'Nordafrika',
	'017' => 'Centralafrika',
	'018' => 'Det sydlige Afrika',
	'019' => 'Nord-, Mellem- og Sydamerika',
	'021' => 'Det nordlige Amerika',
	'029' => 'Caribien',
	'030' => 'Østasien',
	'034' => 'Sydasien',
	'035' => 'Sydøstasien',
	'039' => 'Sydeuropa',
	'053' => 'Australasien',
	'054' => 'Melanesien',
	'057' => 'Mikronesiske område',
	'061' => 'Polynesien',
	'142' => 'Asien',
	'143' => 'Centralasien',
	'145' => 'Vestasien',
	'150' => 'Europa',
	'151' => 'Østeuropa',
	'154' => 'Nordeuropa',
	'155' => 'Vesteuropa',
	'202' => 'Subsaharisk Afrika',
	'419' => 'Latinamerika',
	'AC' => 'Ascensionøen',
	'AD' => 'Andorra',
	'AE' => 'De Forenede Arabiske Emirater',
	'AF' => 'Afghanistan',
	'AG' => 'Antigua og Barbuda',
	'AI' => 'Anguilla',
	'AL' => 'Albanien',
	'AM' => 'Armenien',
	'AO' => 'Angola',
	'AQ' => 'Antarktis',
	'AR' => 'Argentina',
	'AS' => 'Amerikansk Samoa',
	'AT' => 'Østrig',
	'AU' => 'Australien',
	'AW' => 'Aruba',
	'AX' => 'Åland',
	'AZ' => 'Aserbajdsjan',
	'BA' => 'Bosnien-Hercegovina',
	'BB' => 'Barbados',
	'BD' => 'Bangladesh',
	'BE' => 'Belgien',
	'BF' => 'Burkina Faso',
	'BG' => 'Bulgarien',
	'BH' => 'Bahrain',
	'BI' => 'Burundi',
	'BJ' => 'Benin',
	'BL' => 'Saint Barthélemy',
	'BM' => 'Bermuda',
	'BN' => 'Brunei',
	'BO' => 'Bolivia',
	'BQ' => 'De tidligere Nederlandske Antiller',
	'BR' => 'Brasilien',
	'BS' => 'Bahamas',
	'BT' => 'Bhutan',
	'BV' => 'Bouvetøen',
	'BW' => 'Botswana',
	'BY' => 'Belarus',
	'BZ' => 'Belize',
	'CA' => 'Canada',
	'CC' => 'Cocosøerne',
	'CD' => 'Congo-Kinshasa',
	'CD@alt=variant' => 'Den Demokratiske Republik Congo (DRC)',
	'CF' => 'Den Centralafrikanske Republik',
	'CG' => 'Congo-Brazzaville',
	'CG@alt=variant' => 'Republikken Congo',
	'CH' => 'Schweiz',
	'CI' => 'Elfenbenskysten',
	'CK' => 'Cookøerne',
	'CL' => 'Chile',
	'CM' => 'Cameroun',
	'CN' => 'Kina',
	'CO' => 'Colombia',
	'CP' => 'Clippertonøen',
	'CR' => 'Costa Rica',
	'CU' => 'Cuba',
	'CV' => 'Kap Verde',
	'CW' => 'Curaçao',
	'CX' => 'Juleøen',
	'CY' => 'Cypern',
	'CZ' => 'Tjekkiet',
	'CZ@alt=variant' => 'Den Tjekkiske Republik',
	'DE' => 'Tyskland',
	'DG' => 'Diego Garcia',
	'DJ' => 'Djibouti',
	'DK' => 'Danmark',
	'DM' => 'Dominica',
	'DO' => 'Den Dominikanske Republik',
	'DZ' => 'Algeriet',
	'EA' => 'Ceuta og Melilla',
	'EC' => 'Ecuador',
	'EE' => 'Estland',
	'EG' => 'Egypten',
	'EH' => 'Vestsahara',
	'ER' => 'Eritrea',
	'ES' => 'Spanien',
	'ET' => 'Etiopien',
	'EU' => 'Den Europæiske Union',
	'EZ' => 'eurozonen',
	'FI' => 'Finland',
	'FJ' => 'Fiji',
	'FK' => 'Falklandsøerne',
	'FK@alt=variant' => 'Falklandsøerne (Islas Malvinas)',
	'FM' => 'Mikronesien',
	'FO' => 'Færøerne',
	'FR' => 'Frankrig',
	'GA' => 'Gabon',
	'GB' => 'Storbritannien',
	'GD' => 'Grenada',
	'GE' => 'Georgien',
	'GF' => 'Fransk Guyana',
	'GG' => 'Guernsey',
	'GH' => 'Ghana',
	'GI' => 'Gibraltar',
	'GL' => 'Grønland',
	'GM' => 'Gambia',
	'GN' => 'Guinea',
	'GP' => 'Guadeloupe',
	'GQ' => 'Ækvatorialguinea',
	'GR' => 'Grækenland',
	'GS' => 'South Georgia og De Sydlige Sandwichøer',
	'GT' => 'Guatemala',
	'GU' => 'Guam',
	'GW' => 'Guinea-Bissau',
	'GY' => 'Guyana',
	'HK' => 'SAR Hongkong',
	'HK@alt=short' => 'Hongkong',
	'HM' => 'Heard Island og McDonald Islands',
	'HN' => 'Honduras',
	'HR' => 'Kroatien',
	'HT' => 'Haiti',
	'HU' => 'Ungarn',
	'IC' => 'Kanariske øer',
	'ID' => 'Indonesien',
	'IE' => 'Irland',
	'IL' => 'Israel',
	'IM' => 'Isle of Man',
	'IN' => 'Indien',
	'IO' => 'Det Britiske Territorium i Det Indiske Ocean',
    'IO@alt=chagos' => 'Chagosøerne',
	'IQ' => 'Irak',
	'IR' => 'Iran',
	'IS' => 'Island',
	'IT' => 'Italien',
	'JE' => 'Jersey',
	'JM' => 'Jamaica',
	'JO' => 'Jordan',
	'JP' => 'Japan',
	'KE' => 'Kenya',
	'KG' => 'Kirgisistan',
	'KH' => 'Cambodja',
	'KI' => 'Kiribati',
	'KM' => 'Comorerne',
	'KN' => 'Saint Kitts og Nevis',
	'KP' => 'Nordkorea',
	'KR' => 'Sydkorea',
	'KW' => 'Kuwait',
	'KY' => 'Caymanøerne',
	'KZ' => 'Kasakhstan',
	'LA' => 'Laos',
	'LB' => 'Libanon',
	'LC' => 'Saint Lucia',
	'LI' => 'Liechtenstein',
	'LK' => 'Sri Lanka',
	'LR' => 'Liberia',
	'LS' => 'Lesotho',
	'LT' => 'Litauen',
	'LU' => 'Luxembourg',
	'LV' => 'Letland',
	'LY' => 'Libyen',
	'MA' => 'Marokko',
	'MC' => 'Monaco',
	'MD' => 'Moldova',
	'ME' => 'Montenegro',
	'MF' => 'Saint Martin',
	'MG' => 'Madagaskar',
	'MH' => 'Marshalløerne',
	'MK' => 'Nordmakedonien',
	'ML' => 'Mali',
	'MM' => 'Myanmar (Burma)',
	'MN' => 'Mongoliet',
	'MO' => 'SAR Macao',
	'MO@alt=short' => 'Macao',
	'MP' => 'Nordmarianerne',
	'MQ' => 'Martinique',
	'MR' => 'Mauretanien',
	'MS' => 'Montserrat',
	'MT' => 'Malta',
	'MU' => 'Mauritius',
	'MV' => 'Maldiverne',
	'MW' => 'Malawi',
	'MX' => 'Mexico',
	'MY' => 'Malaysia',
	'MZ' => 'Mozambique',
	'NA' => 'Namibia',
	'NC' => 'Ny Kaledonien',
	'NE' => 'Niger',
	'NF' => 'Norfolk Island',
	'NG' => 'Nigeria',
	'NI' => 'Nicaragua',
	'NL' => 'Nederlandene',
	'NO' => 'Norge',
	'NP' => 'Nepal',
	'NR' => 'Nauru',
	'NU' => 'Niue',
	'NZ' => 'New Zealand',
    'NZ@alt=variant' => 'Aotearoa New Zealand',
	'OM' => 'Oman',
	'PA' => 'Panama',
	'PE' => 'Peru',
	'PF' => 'Fransk Polynesien',
	'PG' => 'Papua Ny Guinea',
	'PH' => 'Filippinerne',
	'PK' => 'Pakistan',
	'PL' => 'Polen',
	'PM' => 'Saint Pierre og Miquelon',
	'PN' => 'Pitcairn',
	'PR' => 'Puerto Rico',
	'PS' => 'De palæstinensiske områder',
	'PS@alt=short' => 'Palæstina',
	'PT' => 'Portugal',
	'PW' => 'Palau',
	'PY' => 'Paraguay',
	'QA' => 'Qatar',
	'QO' => 'Ydre Oceanien',
	'RE' => 'Réunion',
	'RO' => 'Rumænien',
	'RS' => 'Serbien',
	'RU' => 'Rusland',
	'RW' => 'Rwanda',
	'SA' => 'Saudi-Arabien',
	'SB' => 'Salomonøerne',
	'SC' => 'Seychellerne',
	'SD' => 'Sudan',
	'SE' => 'Sverige',
	'SG' => 'Singapore',
	'SH' => 'St. Helena',
	'SI' => 'Slovenien',
	'SJ' => 'Svalbard og Jan Mayen',
	'SK' => 'Slovakiet',
	'SL' => 'Sierra Leone',
	'SM' => 'San Marino',
	'SN' => 'Senegal',
	'SO' => 'Somalia',
	'SR' => 'Surinam',
	'SS' => 'Sydsudan',
	'ST' => 'São Tomé og Príncipe',
	'SV' => 'El Salvador',
	'SX' => 'Sint Maarten',
	'SY' => 'Syrien',
	'SZ' => 'Eswatini',
	'SZ@alt=variant' => 'Swaziland',
	'TA' => 'Tristan da Cunha',
	'TC' => 'Turks- og Caicosøerne',
	'TD' => 'Tchad',
	'TF' => 'De Franske Besiddelser i Det Sydlige Indiske Ocean og Antarktis',
	'TG' => 'Togo',
	'TH' => 'Thailand',
	'TJ' => 'Tadsjikistan',
	'TK' => 'Tokelau',
	'TL' => 'Timor-Leste',
	'TL@alt=variant' => 'Østtimor',
	'TM' => 'Turkmenistan',
	'TN' => 'Tunesien',
	'TO' => 'Tonga',
	'TR' => 'Tyrkiet',
	'TT' => 'Trinidad og Tobago',
	'TV' => 'Tuvalu',
	'TW' => 'Taiwan',
	'TZ' => 'Tanzania',
	'UA' => 'Ukraine',
	'UG' => 'Uganda',
	'UM' => 'Amerikanske oversøiske øer',
	'UN' => 'De Forenede Nationer',
	'UN@alt=short' => 'FN',
	'US' => 'USA',
	'UY' => 'Uruguay',
	'UZ' => 'Usbekistan',
	'VA' => 'Vatikanstaten',
	'VC' => 'Saint Vincent og Grenadinerne',
	'VE' => 'Venezuela',
	'VG' => 'De Britiske Jomfruøer',
	'VI' => 'De Amerikanske Jomfruøer',
	'VN' => 'Vietnam',
	'VU' => 'Vanuatu',
	'WF' => 'Wallis og Futuna',
	'WS' => 'Samoa',
	'XA' => 'pseudo-accenter',
	'XB' => 'pseudo-bidi',
	'XK' => 'Kosovo',
	'YE' => 'Yemen',
	'YT' => 'Mayotte',
	'ZA' => 'Sydafrika',
	'ZM' => 'Zambia',
	'ZW' => 'Zimbabwe',
	'ZZ' => 'Ukendt område',
};

is_deeply($locale->all_regions(), $all_regions, 'All Regions');

is($locale->variant_name(), '', 'Variant name from current locale');
is($locale->variant_name('BOHORIC'), 'Bohorič-alfabet', 'Variant name from string');
is($locale->variant_name($other_locale), '', 'Variant name from other locale object');

is($locale->key_name('colCaseLevel'), 'Sortering med forskel på små og store bogstaver', 'Key name from string');

is($locale->type_name(colCaseFirst => 'lower'), 'Sortér med små bogstaver først', 'Type name from string');

is($locale->measurement_system_name('metric'), 'det metriske system', 'Measurement system name English Metric');
is($locale->measurement_system_name('us'), 'de amerikanske målesystemer', 'Measurement system name English US');
is($locale->measurement_system_name('uk'), 'de britiske målesystemer', 'Measurement system name English UK');